## ---------------------------------------------------------------------
##
## Copyright (C) 2012 - 2015 by the deal.II authors
##
## This file is part of the deal.II library.
##
## The deal.II library is free software; you can use it, redistribute
## it, and/or modify it under the terms of the GNU Lesser General
## Public License as published by the Free Software Foundation; either
## version 2.1 of the License, or (at your option) any later version.
## The full text of the license can be found in the file LICENSE at
## the top level of the deal.II distribution.
##
## ---------------------------------------------------------------------


########################################################################
##                                                                    ##
##               The deal.II project configuration file               ##
##                                                                    ##
########################################################################


#
# General information
#

SET(DEAL_II_PACKAGE_NAME "deal.II")
SET(DEAL_II_PACKAGE_VERSION "8.4.2")
SET(DEAL_II_PACKAGE_VENDOR "The deal.II Authors <http://www.dealii.org/>")
SET(DEAL_II_PACKAGE_DESCRIPTION "Library for solving partial differential equations with the finite element method")

SET(DEAL_II_VERSION_MAJOR "8")
SET(DEAL_II_VERSION_MINOR "4")
SET(DEAL_II_VERSION_SUBMINOR "2")
SET(DEAL_II_VERSION "8.4.2")

SET(DEAL_II_GIT_BRANCH "")
SET(DEAL_II_GIT_REVISION "")
SET(DEAL_II_GIT_SHORTREV "")

SET(DEAL_II_PROJECT_CONFIG_NAME "deal.II")

SET(DEAL_II_BUILD_TYPE "DebugRelease")
SET(DEAL_II_BUILD_TYPES "DEBUG;RELEASE")


#
# Information about the project location
#

SET(DEAL_II_DOCHTML_RELDIR "share/doc/libdeal.ii-doc/html")
SET(DEAL_II_DOCREADME_RELDIR "share/doc/libdeal.ii-doc")
SET(DEAL_II_EXAMPLES_RELDIR "share/doc/libdeal.ii-doc/examples")
SET(DEAL_II_EXECUTABLE_RELDIR "bin")
SET(DEAL_II_INCLUDE_RELDIR "include")
SET(DEAL_II_LIBRARY_RELDIR "lib/s390x-linux-gnu")
SET(DEAL_II_PROJECT_CONFIG_RELDIR "share/cmake/deal.II")
SET(DEAL_II_SHARE_RELDIR "share/deal.ii/")

#
# Determine DEAL_II_PATH from CMAKE_CURRENT_LIST_DIR:
#

SET(DEAL_II_PATH "${CMAKE_CURRENT_LIST_DIR}")
SET(_path "${DEAL_II_PROJECT_CONFIG_RELDIR}")
WHILE(NOT "${_path}" STREQUAL "")
  GET_FILENAME_COMPONENT(DEAL_II_PATH "${DEAL_II_PATH}" PATH)
  GET_FILENAME_COMPONENT(_path "${_path}" PATH)
ENDWHILE()

#
# Print a message after inclusion of this file:
#

SET(DEAL_II_PROJECT_CONFIG_INCLUDED TRUE)

SET(DEAL_II_BUILD_DIR FALSE)

IF(NOT ${DEAL_II_PACKAGE_NAME}_FIND_QUIETLY)
  IF(DEAL_II_BUILD_DIR)
    MESSAGE(STATUS
      "Using the ${DEAL_II_PACKAGE_NAME}-${DEAL_II_PACKAGE_VERSION} build directory found at ${DEAL_II_PATH}"
      )
  ELSE()
    MESSAGE(STATUS
      "Using the ${DEAL_II_PACKAGE_NAME}-${DEAL_II_PACKAGE_VERSION} installation found at ${DEAL_II_PATH}"
      )
  ENDIF()
ENDIF()


#
# Include all convenience macros:
#

FILE(GLOB _macro_files
  "${DEAL_II_PATH}/${DEAL_II_SHARE_RELDIR}/macros/*.cmake"
  )
FOREACH(file ${_macro_files})
  IF(NOT ${DEAL_II_PACKAGE_NAME}_FIND_QUIETLY)
    MESSAGE(STATUS "Include macro ${file}")
  ENDIF()
  INCLUDE(${file})
ENDFOREACH()


#
# Compiler and linker configuration
#

SET(DEAL_II_CXX_COMPILER "/usr/bin/c++")
SET(DEAL_II_C_COMPILER "/usr/bin/cc")

# used for all targets:
SET(DEAL_II_CXX_FLAGS "-pedantic -fPIC -Wall -Wextra -Wpointer-arith -Wwrite-strings -Wsynth -Wsign-compare -Wswitch -Woverloaded-virtual -Wno-long-long  -Wno-literal-suffix -fopenmp-simd -std=c++14 -g -O2 -fdebug-prefix-map=/build/deal.ii-GTeWqA/deal.ii-8.4.2=. -fstack-protector-strong -Wformat -Werror=format-security -Wdate-time -D_FORTIFY_SOURCE=2 -Wno-nonnull-compare -Wno-address -Wno-unused-local-typedefs")

# _additionally_ used for debug targets:
SET(DEAL_II_CXX_FLAGS_DEBUG "-Og -ggdb -Wa,--compress-debug-sections")

# _additionally_ used for release targets:
SET(DEAL_II_CXX_FLAGS_RELEASE "-O2 -funroll-loops -funroll-all-loops -fstrict-aliasing")

# used for all targets:
SET(DEAL_II_LINKER_FLAGS "-rdynamic -Wl,-Bsymbolic-functions -Wl,-z,relro -pthread")

# _additionally_ used for debug targets:
SET(DEAL_II_LINKER_FLAGS_DEBUG "-ggdb")

# _additionally_ used for release targets:
SET(DEAL_II_LINKER_FLAGS_RELEASE "")

# used for all targets:
SET(DEAL_II_USER_DEFINITIONS "")

# _additionally_ used for debug targets:
SET(DEAL_II_USER_DEFINITIONS_DEBUG "DEBUG")

# _additionally_ used for release targets:
SET(DEAL_II_USER_DEFINITIONS_RELEASE "")

#
# MPI runtime:
#

SET(DEAL_II_MPIEXEC "/usr/bin/mpiexec")
SET(DEAL_II_MPIEXEC_NUMPROC_FLAG "-np")
SET(DEAL_II_MPIEXEC_PREFLAGS "")
SET(DEAL_II_MPIEXEC_POSTFLAGS "")

#
# Build a static executable:
#

SET(DEAL_II_STATIC_EXECUTABLE "OFF")


#
# Information about include directories and libraries
#

# Full list of include directories:
SET(DEAL_II_INCLUDE_DIRS "${DEAL_II_PATH}/${DEAL_II_INCLUDE_RELDIR};${DEAL_II_PATH}/${DEAL_II_INCLUDE_RELDIR}/deal.II/bundled;/usr/lib/s390x-linux-gnu/openmpi/include/openmpi;/usr/lib/s390x-linux-gnu/openmpi/include/openmpi/opal/mca/event/libevent2022/libevent;/usr/lib/s390x-linux-gnu/openmpi/include/openmpi/opal/mca/event/libevent2022/libevent/include;/usr/lib/s390x-linux-gnu/openmpi/include;/usr/include;/usr/include/trilinos;/usr/include/hdf5/openmpi;/usr/include/suitesparse;/usr/include/petsc;/usr/lib/s390x-linux-gnu/hdf5/openmpi/include;/usr/include/oce;/usr/include/slepc")

# Full list of libraries for the debug target:
SET(DEAL_II_LIBRARIES_DEBUG "${DEAL_II_PATH}/lib/s390x-linux-gnu/libdeal.ii.g.so;/usr/lib/s390x-linux-gnu/libbz2.so;/usr/lib/s390x-linux-gnu/openmpi/lib/libmpi_usempif08.so;/usr/lib/s390x-linux-gnu/openmpi/lib/libmpi_usempi_ignore_tkr.so;/usr/lib/s390x-linux-gnu/openmpi/lib/libmpi_mpifh.so;/usr/lib/s390x-linux-gnu/libtrilinos_pike-blackbox.so;/usr/lib/s390x-linux-gnu/libtrilinos_trilinoscouplings.so;/usr/lib/s390x-linux-gnu/libtrilinos_piro.so;/usr/lib/s390x-linux-gnu/libtrilinos_rol.so;/usr/lib/s390x-linux-gnu/libtrilinos_stokhos_muelu.so;/usr/lib/s390x-linux-gnu/libtrilinos_stokhos_ifpack2.so;/usr/lib/s390x-linux-gnu/libtrilinos_stokhos_amesos2.so;/usr/lib/s390x-linux-gnu/libtrilinos_stokhos_tpetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_stokhos_sacado.so;/usr/lib/s390x-linux-gnu/libtrilinos_stokhos.so;/usr/lib/s390x-linux-gnu/libtrilinos_rythmos.so;/usr/lib/s390x-linux-gnu/libtrilinos_muelu-adapters.so;/usr/lib/s390x-linux-gnu/libtrilinos_muelu-interface.so;/usr/lib/s390x-linux-gnu/libtrilinos_muelu.so;/usr/lib/s390x-linux-gnu/libtrilinos_moertel.so;/usr/lib/s390x-linux-gnu/libtrilinos_locathyra.so;/usr/lib/s390x-linux-gnu/libtrilinos_locaepetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_localapack.so;/usr/lib/s390x-linux-gnu/libtrilinos_loca.so;/usr/lib/s390x-linux-gnu/libtrilinos_noxepetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_noxlapack.so;/usr/lib/s390x-linux-gnu/libtrilinos_nox.so;/usr/lib/s390x-linux-gnu/libtrilinos_phalanx.so;/usr/lib/s390x-linux-gnu/libtrilinos_intrepid.so;/usr/lib/s390x-linux-gnu/libtrilinos_teko.so;/usr/lib/s390x-linux-gnu/libtrilinos_stratimikos.so;/usr/lib/s390x-linux-gnu/libtrilinos_stratimikosbelos.so;/usr/lib/s390x-linux-gnu/libtrilinos_stratimikosaztecoo.so;/usr/lib/s390x-linux-gnu/libtrilinos_stratimikosamesos.so;/usr/lib/s390x-linux-gnu/libtrilinos_stratimikosml.so;/usr/lib/s390x-linux-gnu/libtrilinos_stratimikosifpack.so;/usr/lib/s390x-linux-gnu/libtrilinos_ifpack2-adapters.so;/usr/lib/s390x-linux-gnu/libtrilinos_ifpack2.so;/usr/lib/s390x-linux-gnu/libtrilinos_anasazitpetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_ModeLaplace.so;/usr/lib/s390x-linux-gnu/libtrilinos_anasaziepetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_anasazi.so;/usr/lib/s390x-linux-gnu/libtrilinos_komplex.so;/usr/lib/s390x-linux-gnu/libtrilinos_amesos2.so;/usr/lib/s390x-linux-gnu/libtrilinos_shylu.so;/usr/lib/s390x-linux-gnu/libtrilinos_belostpetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_belosepetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_belos.so;/usr/lib/s390x-linux-gnu/libtrilinos_ml.so;/usr/lib/s390x-linux-gnu/libtrilinos_ifpack.so;/usr/lib/s390x-linux-gnu/libtrilinos_zoltan2.so;/usr/lib/s390x-linux-gnu/libtrilinos_pamgen_extras.so;/usr/lib/s390x-linux-gnu/libtrilinos_pamgen.so;/usr/lib/s390x-linux-gnu/libtrilinos_amesos.so;/usr/lib/s390x-linux-gnu/libtrilinos_galeri-xpetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_galeri-epetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_aztecoo.so;/usr/lib/s390x-linux-gnu/libtrilinos_dpliris.so;/usr/lib/s390x-linux-gnu/libtrilinos_isorropia.so;/usr/lib/s390x-linux-gnu/libtrilinos_optipack.so;/usr/lib/s390x-linux-gnu/libtrilinos_xpetra-sup.so;/usr/lib/s390x-linux-gnu/libtrilinos_xpetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_thyratpetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_thyraepetraext.so;/usr/lib/s390x-linux-gnu/libtrilinos_thyraepetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_thyracore.so;/usr/lib/s390x-linux-gnu/libtrilinos_epetraext.so;/usr/lib/s390x-linux-gnu/libtrilinos_tpetraext.so;/usr/lib/s390x-linux-gnu/libtrilinos_tpetrainout.so;/usr/lib/s390x-linux-gnu/libtrilinos_tpetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_kokkostsqr.so;/usr/lib/s390x-linux-gnu/libtrilinos_tpetrakernels.so;/usr/lib/s390x-linux-gnu/libtrilinos_tpetraclassiclinalg.so;/usr/lib/s390x-linux-gnu/libtrilinos_tpetraclassicnodeapi.so;/usr/lib/s390x-linux-gnu/libtrilinos_tpetraclassic.so;/usr/lib/s390x-linux-gnu/libtrilinos_triutils.so;/usr/lib/s390x-linux-gnu/libtrilinos_globipack.so;/usr/lib/s390x-linux-gnu/libtrilinos_shards.so;/usr/lib/s390x-linux-gnu/libtrilinos_zoltan.so;/usr/lib/s390x-linux-gnu/libtrilinos_epetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_sacado.so;/usr/lib/s390x-linux-gnu/libtrilinos_rtop.so;/usr/lib/s390x-linux-gnu/libtrilinos_teuchoskokkoscomm.so;/usr/lib/s390x-linux-gnu/libtrilinos_teuchoskokkoscompat.so;/usr/lib/s390x-linux-gnu/libtrilinos_teuchosremainder.so;/usr/lib/s390x-linux-gnu/libtrilinos_teuchosnumerics.so;/usr/lib/s390x-linux-gnu/libtrilinos_teuchoscomm.so;/usr/lib/s390x-linux-gnu/libtrilinos_teuchosparameterlist.so;/usr/lib/s390x-linux-gnu/libtrilinos_teuchoscore.so;/usr/lib/s390x-linux-gnu/libtrilinos_kokkosalgorithms.so;/usr/lib/s390x-linux-gnu/libtrilinos_kokkoscontainers.so;/usr/lib/s390x-linux-gnu/libtrilinos_kokkoscore.so;/usr/lib/libsmumps.so;/usr/lib/libdmumps.so;/usr/lib/libcmumps.so;/usr/lib/libzmumps.so;/usr/lib/libpord.so;/usr/lib/libmumps_common.so;/usr/lib/s390x-linux-gnu/hdf5/openmpi/libhdf5.so;/usr/lib/s390x-linux-gnu/libtbb.so;/usr/lib/s390x-linux-gnu/libz.so;dl;/usr/lib/s390x-linux-gnu/openmpi/lib/libmpi_cxx.so;/usr/lib/s390x-linux-gnu/libumfpack.so;/usr/lib/s390x-linux-gnu/libcholmod.so;/usr/lib/s390x-linux-gnu/libccolamd.so;/usr/lib/s390x-linux-gnu/libcolamd.so;/usr/lib/s390x-linux-gnu/libcamd.so;/usr/lib/s390x-linux-gnu/libsuitesparseconfig.so;/usr/lib/s390x-linux-gnu/libamd.so;rt;/usr/lib/libparpack.so;/usr/lib/libarpack.so;/usr/lib/s390x-linux-gnu/libboost_iostreams.so;/usr/lib/s390x-linux-gnu/libboost_serialization.so;/usr/lib/s390x-linux-gnu/libboost_system.so;/usr/lib/s390x-linux-gnu/libboost_thread.so;/usr/lib/s390x-linux-gnu/libboost_regex.so;/usr/lib/s390x-linux-gnu/libboost_chrono.so;/usr/lib/s390x-linux-gnu/libboost_date_time.so;/usr/lib/s390x-linux-gnu/libboost_atomic.so;pthread;/usr/lib/s390x-linux-gnu/hdf5/openmpi/lib/lib/libhdf5_hl.so;/usr/lib/s390x-linux-gnu/hdf5/openmpi/lib/lib/libhdf5.so;/usr/lib/s390x-linux-gnu/libmuparser.so;/usr/lib/s390x-linux-gnu/libnetcdf_c++.so;/usr/lib/s390x-linux-gnu/libnetcdf.so;/usr/lib/s390x-linux-gnu/libTKBO.so;/usr/lib/s390x-linux-gnu/libTKBool.so;/usr/lib/s390x-linux-gnu/libTKBRep.so;/usr/lib/s390x-linux-gnu/libTKernel.so;/usr/lib/s390x-linux-gnu/libTKFeat.so;/usr/lib/s390x-linux-gnu/libTKFillet.so;/usr/lib/s390x-linux-gnu/libTKG2d.so;/usr/lib/s390x-linux-gnu/libTKG3d.so;/usr/lib/s390x-linux-gnu/libTKGeomAlgo.so;/usr/lib/s390x-linux-gnu/libTKGeomBase.so;/usr/lib/s390x-linux-gnu/libTKHLR.so;/usr/lib/s390x-linux-gnu/libTKIGES.so;/usr/lib/s390x-linux-gnu/libTKMath.so;/usr/lib/s390x-linux-gnu/libTKMesh.so;/usr/lib/s390x-linux-gnu/libTKOffset.so;/usr/lib/s390x-linux-gnu/libTKPrim.so;/usr/lib/s390x-linux-gnu/libTKShHealing.so;/usr/lib/s390x-linux-gnu/libTKSTEP.so;/usr/lib/s390x-linux-gnu/libTKSTEPAttr.so;/usr/lib/s390x-linux-gnu/libTKSTEPBase.so;/usr/lib/s390x-linux-gnu/libTKSTL.so;/usr/lib/s390x-linux-gnu/libTKTopAlgo.so;/usr/lib/s390x-linux-gnu/libTKXSBase.so;/usr/lib/s390x-linux-gnu/libp4est.so;/usr/lib/s390x-linux-gnu/libsc.so;/usr/lib/liblapack.so;/usr/lib/libblas.so;gfortran;m;c;/usr/lib/s390x-linux-gnu/openmpi/lib/libmpi.so;/usr/lib/s390x-linux-gnu/libslepc.so;/usr/lib/s390x-linux-gnu/libpetsc.so")

# Full list of libraries for the release target:
SET(DEAL_II_LIBRARIES_RELEASE "${DEAL_II_PATH}/lib/s390x-linux-gnu/libdeal.ii.so;/usr/lib/s390x-linux-gnu/libbz2.so;/usr/lib/s390x-linux-gnu/openmpi/lib/libmpi_usempif08.so;/usr/lib/s390x-linux-gnu/openmpi/lib/libmpi_usempi_ignore_tkr.so;/usr/lib/s390x-linux-gnu/openmpi/lib/libmpi_mpifh.so;/usr/lib/s390x-linux-gnu/libtrilinos_pike-blackbox.so;/usr/lib/s390x-linux-gnu/libtrilinos_trilinoscouplings.so;/usr/lib/s390x-linux-gnu/libtrilinos_piro.so;/usr/lib/s390x-linux-gnu/libtrilinos_rol.so;/usr/lib/s390x-linux-gnu/libtrilinos_stokhos_muelu.so;/usr/lib/s390x-linux-gnu/libtrilinos_stokhos_ifpack2.so;/usr/lib/s390x-linux-gnu/libtrilinos_stokhos_amesos2.so;/usr/lib/s390x-linux-gnu/libtrilinos_stokhos_tpetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_stokhos_sacado.so;/usr/lib/s390x-linux-gnu/libtrilinos_stokhos.so;/usr/lib/s390x-linux-gnu/libtrilinos_rythmos.so;/usr/lib/s390x-linux-gnu/libtrilinos_muelu-adapters.so;/usr/lib/s390x-linux-gnu/libtrilinos_muelu-interface.so;/usr/lib/s390x-linux-gnu/libtrilinos_muelu.so;/usr/lib/s390x-linux-gnu/libtrilinos_moertel.so;/usr/lib/s390x-linux-gnu/libtrilinos_locathyra.so;/usr/lib/s390x-linux-gnu/libtrilinos_locaepetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_localapack.so;/usr/lib/s390x-linux-gnu/libtrilinos_loca.so;/usr/lib/s390x-linux-gnu/libtrilinos_noxepetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_noxlapack.so;/usr/lib/s390x-linux-gnu/libtrilinos_nox.so;/usr/lib/s390x-linux-gnu/libtrilinos_phalanx.so;/usr/lib/s390x-linux-gnu/libtrilinos_intrepid.so;/usr/lib/s390x-linux-gnu/libtrilinos_teko.so;/usr/lib/s390x-linux-gnu/libtrilinos_stratimikos.so;/usr/lib/s390x-linux-gnu/libtrilinos_stratimikosbelos.so;/usr/lib/s390x-linux-gnu/libtrilinos_stratimikosaztecoo.so;/usr/lib/s390x-linux-gnu/libtrilinos_stratimikosamesos.so;/usr/lib/s390x-linux-gnu/libtrilinos_stratimikosml.so;/usr/lib/s390x-linux-gnu/libtrilinos_stratimikosifpack.so;/usr/lib/s390x-linux-gnu/libtrilinos_ifpack2-adapters.so;/usr/lib/s390x-linux-gnu/libtrilinos_ifpack2.so;/usr/lib/s390x-linux-gnu/libtrilinos_anasazitpetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_ModeLaplace.so;/usr/lib/s390x-linux-gnu/libtrilinos_anasaziepetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_anasazi.so;/usr/lib/s390x-linux-gnu/libtrilinos_komplex.so;/usr/lib/s390x-linux-gnu/libtrilinos_amesos2.so;/usr/lib/s390x-linux-gnu/libtrilinos_shylu.so;/usr/lib/s390x-linux-gnu/libtrilinos_belostpetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_belosepetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_belos.so;/usr/lib/s390x-linux-gnu/libtrilinos_ml.so;/usr/lib/s390x-linux-gnu/libtrilinos_ifpack.so;/usr/lib/s390x-linux-gnu/libtrilinos_zoltan2.so;/usr/lib/s390x-linux-gnu/libtrilinos_pamgen_extras.so;/usr/lib/s390x-linux-gnu/libtrilinos_pamgen.so;/usr/lib/s390x-linux-gnu/libtrilinos_amesos.so;/usr/lib/s390x-linux-gnu/libtrilinos_galeri-xpetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_galeri-epetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_aztecoo.so;/usr/lib/s390x-linux-gnu/libtrilinos_dpliris.so;/usr/lib/s390x-linux-gnu/libtrilinos_isorropia.so;/usr/lib/s390x-linux-gnu/libtrilinos_optipack.so;/usr/lib/s390x-linux-gnu/libtrilinos_xpetra-sup.so;/usr/lib/s390x-linux-gnu/libtrilinos_xpetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_thyratpetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_thyraepetraext.so;/usr/lib/s390x-linux-gnu/libtrilinos_thyraepetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_thyracore.so;/usr/lib/s390x-linux-gnu/libtrilinos_epetraext.so;/usr/lib/s390x-linux-gnu/libtrilinos_tpetraext.so;/usr/lib/s390x-linux-gnu/libtrilinos_tpetrainout.so;/usr/lib/s390x-linux-gnu/libtrilinos_tpetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_kokkostsqr.so;/usr/lib/s390x-linux-gnu/libtrilinos_tpetrakernels.so;/usr/lib/s390x-linux-gnu/libtrilinos_tpetraclassiclinalg.so;/usr/lib/s390x-linux-gnu/libtrilinos_tpetraclassicnodeapi.so;/usr/lib/s390x-linux-gnu/libtrilinos_tpetraclassic.so;/usr/lib/s390x-linux-gnu/libtrilinos_triutils.so;/usr/lib/s390x-linux-gnu/libtrilinos_globipack.so;/usr/lib/s390x-linux-gnu/libtrilinos_shards.so;/usr/lib/s390x-linux-gnu/libtrilinos_zoltan.so;/usr/lib/s390x-linux-gnu/libtrilinos_epetra.so;/usr/lib/s390x-linux-gnu/libtrilinos_sacado.so;/usr/lib/s390x-linux-gnu/libtrilinos_rtop.so;/usr/lib/s390x-linux-gnu/libtrilinos_teuchoskokkoscomm.so;/usr/lib/s390x-linux-gnu/libtrilinos_teuchoskokkoscompat.so;/usr/lib/s390x-linux-gnu/libtrilinos_teuchosremainder.so;/usr/lib/s390x-linux-gnu/libtrilinos_teuchosnumerics.so;/usr/lib/s390x-linux-gnu/libtrilinos_teuchoscomm.so;/usr/lib/s390x-linux-gnu/libtrilinos_teuchosparameterlist.so;/usr/lib/s390x-linux-gnu/libtrilinos_teuchoscore.so;/usr/lib/s390x-linux-gnu/libtrilinos_kokkosalgorithms.so;/usr/lib/s390x-linux-gnu/libtrilinos_kokkoscontainers.so;/usr/lib/s390x-linux-gnu/libtrilinos_kokkoscore.so;/usr/lib/libsmumps.so;/usr/lib/libdmumps.so;/usr/lib/libcmumps.so;/usr/lib/libzmumps.so;/usr/lib/libpord.so;/usr/lib/libmumps_common.so;/usr/lib/s390x-linux-gnu/hdf5/openmpi/libhdf5.so;/usr/lib/s390x-linux-gnu/libtbb.so;/usr/lib/s390x-linux-gnu/libz.so;dl;/usr/lib/s390x-linux-gnu/openmpi/lib/libmpi_cxx.so;/usr/lib/s390x-linux-gnu/libumfpack.so;/usr/lib/s390x-linux-gnu/libcholmod.so;/usr/lib/s390x-linux-gnu/libccolamd.so;/usr/lib/s390x-linux-gnu/libcolamd.so;/usr/lib/s390x-linux-gnu/libcamd.so;/usr/lib/s390x-linux-gnu/libsuitesparseconfig.so;/usr/lib/s390x-linux-gnu/libamd.so;rt;/usr/lib/libparpack.so;/usr/lib/libarpack.so;/usr/lib/s390x-linux-gnu/libboost_iostreams.so;/usr/lib/s390x-linux-gnu/libboost_serialization.so;/usr/lib/s390x-linux-gnu/libboost_system.so;/usr/lib/s390x-linux-gnu/libboost_thread.so;/usr/lib/s390x-linux-gnu/libboost_regex.so;/usr/lib/s390x-linux-gnu/libboost_chrono.so;/usr/lib/s390x-linux-gnu/libboost_date_time.so;/usr/lib/s390x-linux-gnu/libboost_atomic.so;pthread;/usr/lib/s390x-linux-gnu/hdf5/openmpi/lib/lib/libhdf5_hl.so;/usr/lib/s390x-linux-gnu/hdf5/openmpi/lib/lib/libhdf5.so;/usr/lib/s390x-linux-gnu/libmuparser.so;/usr/lib/s390x-linux-gnu/libnetcdf_c++.so;/usr/lib/s390x-linux-gnu/libnetcdf.so;/usr/lib/s390x-linux-gnu/libTKBO.so;/usr/lib/s390x-linux-gnu/libTKBool.so;/usr/lib/s390x-linux-gnu/libTKBRep.so;/usr/lib/s390x-linux-gnu/libTKernel.so;/usr/lib/s390x-linux-gnu/libTKFeat.so;/usr/lib/s390x-linux-gnu/libTKFillet.so;/usr/lib/s390x-linux-gnu/libTKG2d.so;/usr/lib/s390x-linux-gnu/libTKG3d.so;/usr/lib/s390x-linux-gnu/libTKGeomAlgo.so;/usr/lib/s390x-linux-gnu/libTKGeomBase.so;/usr/lib/s390x-linux-gnu/libTKHLR.so;/usr/lib/s390x-linux-gnu/libTKIGES.so;/usr/lib/s390x-linux-gnu/libTKMath.so;/usr/lib/s390x-linux-gnu/libTKMesh.so;/usr/lib/s390x-linux-gnu/libTKOffset.so;/usr/lib/s390x-linux-gnu/libTKPrim.so;/usr/lib/s390x-linux-gnu/libTKShHealing.so;/usr/lib/s390x-linux-gnu/libTKSTEP.so;/usr/lib/s390x-linux-gnu/libTKSTEPAttr.so;/usr/lib/s390x-linux-gnu/libTKSTEPBase.so;/usr/lib/s390x-linux-gnu/libTKSTL.so;/usr/lib/s390x-linux-gnu/libTKTopAlgo.so;/usr/lib/s390x-linux-gnu/libTKXSBase.so;/usr/lib/s390x-linux-gnu/libp4est.so;/usr/lib/s390x-linux-gnu/libsc.so;/usr/lib/liblapack.so;/usr/lib/libblas.so;gfortran;m;c;/usr/lib/s390x-linux-gnu/openmpi/lib/libmpi.so;/usr/lib/s390x-linux-gnu/libslepc.so;/usr/lib/s390x-linux-gnu/libpetsc.so")

# Full list of libraries with "debug" and "optimized" keywords for easy use with TARGET_LINK_LIBRARIES:
SET(DEAL_II_LIBRARIES "debug;${DEAL_II_LIBRARIES_DEBUG};optimized;${DEAL_II_LIBRARIES_RELEASE}")


#
# Information about library targets
#

# The library targets file:
SET(DEAL_II_TARGET_CONFIG "${DEAL_II_PATH}/${DEAL_II_PROJECT_CONFIG_RELDIR}/${DEAL_II_PROJECT_CONFIG_NAME}Targets.cmake")

# The Debug target:
SET(DEAL_II_TARGET_DEBUG "deal.ii.g")

# The Release target:
SET(DEAL_II_TARGET_RELEASE "deal.ii")

# Full list of targets with "debug" and "optimized" keywords for easy use with TARGET_LINK_LIBRARIES:
SET(DEAL_II_TARGET "debug;${DEAL_II_TARGET_DEBUG};optimized;${DEAL_II_TARGET_RELEASE}")


#
# Feature configuration:
#

SET(DEAL_II_WITH_64BIT_INDICES OFF)
SET(DEAL_II_WITH_ARPACK ON)
SET(DEAL_II_WITH_BOOST ON)
SET(DEAL_II_BOOST_VERSION "1.62.0")
SET(DEAL_II_WITH_BZIP2 ON)
SET(DEAL_II_BZIP2_VERSION "1.0.6")
SET(DEAL_II_WITH_CXX11 ON)
SET(DEAL_II_WITH_CXX14 ON)
SET(DEAL_II_WITH_GSL ON)
SET(DEAL_II_WITH_HDF5 ON)
SET(DEAL_II_WITH_LAPACK ON)
SET(DEAL_II_WITH_METIS OFF)
SET(DEAL_II_WITH_MPI ON)
SET(DEAL_II_MPI_VERSION "3.1")
SET(DEAL_II_WITH_MUPARSER ON)
SET(DEAL_II_MUPARSER_VERSION "2.2.3")
SET(DEAL_II_WITH_NETCDF ON)
SET(DEAL_II_WITH_OPENCASCADE ON)
SET(DEAL_II_WITH_P4EST ON)
SET(DEAL_II_P4EST_VERSION "1.1")
SET(DEAL_II_WITH_PETSC ON)
SET(DEAL_II_PETSC_VERSION "3.7.5.0")
SET(DEAL_II_WITH_SLEPC ON)
SET(DEAL_II_SLEPC_VERSION "3.7.3.0")
SET(DEAL_II_WITH_THREADS ON)
SET(DEAL_II_WITH_TRILINOS ON)
SET(DEAL_II_TRILINOS_VERSION "12.10.1")
SET(DEAL_II_WITH_UMFPACK ON)
SET(DEAL_II_UMFPACK_VERSION "5.7.6")
SET(DEAL_II_WITH_ZLIB ON)
SET(DEAL_II_ZLIB_VERSION "1.2.8")
